# EventSpec
#
# Tests for the Shrewd::EventSpec class

require 'shrewd/simulation'
require 'shrewd/entities/event'
require 'shrewd/entities/process'

describe Shrewd::Event do

  # Shared variables
  let(:name) { 'Initial' }
  let(:description) { 'Description' }
  let(:processes) { [ Shrewd::Process.new('Process1'),
                      Shrewd::Process.new('Process2') ] }

  describe "initialization" do

    context "with name only" do
      before :each do
        @event = Shrewd::Event.new(name)
      end

      it "should be valid" do
        expect(@event).to be_an_instance_of Shrewd::Event
        expect(@event.name).to eql name
        expect(@event.description).to be_empty
        expect(@event.processes).to eql Array.new
        expect(@event.action).to be_nil
      end

    end

    context "with all parameters" do
      let(:action) { Proc.new { |variables| } }

      before :each do
        @event = Shrewd::Event.new(name, description, processes, action)
      end

      it "should be valid" do
        expect(@event).to be_an_instance_of Shrewd::Event
        expect(@event.name).to eql name
        expect(@event.description).to eql description
        expect(@event.processes).to eql processes
        expect(@event.action).to eql action
      end
    end
  end
end
